//Регистрация решенных задач
function [err,msg]=RegisteredSolvedTaskFromRezult(SolvedTask,..//Решенная задача
                                                  SolvedTaskMsg,..//Сообщение решенной задачи
                                                  ProjectName,..//Имя проекта
                                                  errPrintMsg..//Необходимость печати сообщений об ошибках
                                                  )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('The function RegisteredSolvedTask takes 2, 3, or 4 arguments');
    end
    select nArg
    case 2 then
        ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
    case 3 then
        if type(ProjectName) == 4 then
            errPrintMsg = ProjectName;
            ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
    end
    
    //Извлекаем из строк последующие задачи, для которых готовы данные
    mMsgs = matrix(stripblanks(strsplit(SolvedTaskMsg,':')),1,-1);//Заголовок и сами задачи
    Header = mMsgs(1);//Заголовок сообщения
    if Header ~= 'Reseivig datas for solving next tasks' then
        err = 3;
        msg = 'The task ' + SolvedTask + ' was solved with error';
        if errPrintMsg then
            error(msg);
        else
            return;
        end
    end
    if size(mMsgs,'*') > 2 then
        SolvedTaskDatasName = stripblanks(mMsgs(2));//Получаем имя данных для последующих задач
        strTasks = mMsgs(3);
    else
        SolvedTaskDatasName = [];
        strTasks = [];
    end
    if ~isempty(strTasks) then
        NextTasksNames = matrix(stripblanks(strsplit(strTasks,',')),1,-1);//Выделяем имена задач
        NextTasksNames = NextTasksNames(length(NextTasksNames) > 0);
        NextTasksNames = unique(NextTasksNames);//Удаляем повторяющиеся элементы
    else
        NextTasksNames = [];
    end
    
    //Регистрируем полученные задачи
    [err,msg]=RegisteredSolvedTask(SolvedTask,SolvedTaskDatasName,..
                                   NextTasksNames,ProjectName,errPrintMsg);
endfunction
